#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-1tbGPupoxtjEQEvi1c3ub3
key:                  asn1-parse-0.9.5-1tbGPupoxtjEQEvi1c3ub3
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  8de54107f282f40699cf0bf628f01dea
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-8.10.5/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/asn1-parse-0.9.5
hs-libraries:         HSasn1-parse-0.9.5-1tbGPupoxtjEQEvi1c3ub3
depends:
    asn1-encoding-0.9.6-6RSJr1YW7043TvuzXEqv2y
    asn1-types-0.3.4-3ohXd9ivbODA8aZEAugckT base-4.14.2.0
    bytestring-0.10.12.0

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

